@@ -27,25 +27,25 @@ import sipconfig, PyQt4.pyqtconfig
 
 # These are installation specific values created when PyKDE was configured.
 # 
-kde_version_parts = '4.13.3'.split('.')
+kde_version_parts = '4.14.10'.split('.')
 kde_version_hex = int(kde_version_parts[0])*65536 + int(kde_version_parts[1])*256 + int(kde_version_parts[2])
 _pkg_config = {
     'dist_name':            '',
     'kde_version':          kde_version_hex,
     'kde_version_extra':    '',
     'kde_version_sfx':      '',
-    'kde_version_str':      '4.13.3',
+    'kde_version_str':      '4.14.10',
     'kdebasedir':           '/usr/local',
     'kdeincdir':            '/usr/local/include/kde4',
     'kdelibdir':            '/usr/local/lib/kde4/libs',
     'konsolepart':          'False',
     'libdir':               'libs',
-    'pykde_kde_sip_flags':  ' -t ALL -t WS_X11 -t Qt_4_8_4  -X VendorID -X PyQt_NoPrintRangeBug -P;-g;-x;PyKDE_QVector;-x;Py_v3',
+    'pykde_kde_sip_flags':  ' -t ALL -t WS_X11 -t Qt_4_8_6  -X VendorID -X PyQt_NoPrintRangeBug -P;-g;-x;PyKDE_QVector;-x;Py_v3;-x;PyKDE_GLuint',
     'pykde_mod_dir':        '/usr/local/lib/python2.7/site-packages/PyKDE4',
-    'pykde_modules':        'kdecore solid kdeui kio kutils kparts ktexteditor dnssd phonon plasma kterminal soprano nepomuk akonadi',
+    'pykde_modules':        '',
     'pykde_sip_dir':        '/usr/local/share/sip/PyKDE4',
     'pykde_version':        kde_version_hex,
-    'pykde_version_str':    '4.13.3'
+    'pykde_version_str':    '4.14.10'
 }
 
 _default_macros = None
